Crate icu_time_data
Data for the icu_time crate
This data was generated with CLDR version 48.0.0, ICU version release-78.1rc, and LSTM segmenter version v0.1.0.
Macros
- impl_
timezone_ identifiers_ iana_ core_ v1 - Implement
DataProvider<TimezoneIdentifiersIanaCoreV1>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
timezone_ identifiers_ iana_ extended_ v1 - Implement
DataProvider<TimezoneIdentifiersIanaExtendedV1>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
timezone_ identifiers_ windows_ v1 - Implement
DataProvider<TimezoneIdentifiersWindowsV1>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - impl_
timezone_ periods_ v1 - Implement
DataProvider<TimezonePeriodsV1>on the given struct using the data hardcoded in this file. This allows the struct to be used withicu’s_unstableconstructors. - make_
provider - Marks a type as a data provider. You can then use macros like
impl_core_helloworld_v1to add implementations.